import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

public class GlobalExceptionHandler {

    public static void main(String[] args) {
        // Set global exception handler
        Thread.setDefaultUncaughtExceptionHandler(new MyExceptionHandler());

        // Simulate an unhandled exception
        System.out.println("Program started...");
        String value = null;
        System.out.println(value.length());  // This will throw NullPointerException
    }

    // Custom global exception handler
    static class MyExceptionHandler implements Thread.UncaughtExceptionHandler {
        @Override
        public void uncaughtException(Thread t, Throwable e) {
            try (PrintWriter writer = new PrintWriter(new FileWriter("error_log.txt", true))) {
                writer.println("=== Uncaught Exception in thread \"" + t.getName() + "\" ===");
                writer.println("Exception: " + e);
                for (StackTraceElement element : e.getStackTrace()) {
                    writer.println("\tat " + element);
                }
                writer.println(); // blank line between exceptions
            } catch (IOException ioException) {
                System.err.println("Failed to write to log file: " + ioException.getMessage());
            }
        }
    }
}


